@@ -8,10 +8,6 @@ module AcceptanceTests
       bundle_version_of('rails')
     end
 
-    def rails_gt_6_0?
-      rails_version > 6.0
-    end
-
     def rails_6_x?
       rails_version =~ '~> 6.0'
     end
