@@ -32,16 +32,6 @@ describe Shoulda::Matchers::ActiveModel::AllowValueMatcher, type: :model do
       expect(matcher.description).to eq 'allow :baz to be ‹"foo"›'
     end
 
-    if active_model_3_2?
-      it 'describes itself with a strict validation' do
-        strict_matcher = allow_value('xyz').for(:attr).strict
-
-        expect(strict_matcher.description).to eq(
-          'allow :attr to be ‹"xyz"›, raising a validation exception on failure',
-        )
-      end
-    end
-
     it 'truncates the description when long' do
       matcher = allow_value('A' * 10000).for(:baz)
 
@@ -353,6 +343,40 @@ errors instead:
 
   context 'when the attribute being validated is different than the attribute that receives the validation error' do
     include UnitTests::AllowValueMatcherHelpers
+    context 'when no validation message was provided directly' do
+      context 'when asserting the negative' do
+        it 'rejects with an appropriate failure message' do
+          builder = builder_for_record_with_unrelated_error
+          assertion = lambda do
+            expect(builder.record).
+              not_to allow_value(builder.valid_value).
+              for(builder.attribute_to_validate)
+          end
+
+          message = <<-MESSAGE
+After setting :attribute_to_validate to ‹"some value"›, the matcher
+expected the Example to be invalid, placing a validation error on
+:attribute_to_validate. The Example was invalid, but it had errors
+involving other attributes:
+
+* attribute_that_receives_error: ["some message"]
+          MESSAGE
+          expect(&assertion).to fail_with_message(message)
+        end
+      end
+    end
+
+    context 'when the attribute that receives the validation error is provided' do
+      context 'given a valid value' do
+        it 'accepts' do
+          builder = builder_for_record_with_different_error_attribute
+          expect(builder.record).
+            to allow_value(builder.valid_value).
+            for(builder.attribute_to_validate).
+            against(builder.attribute_that_receives_error)
+        end
+      end
+    end
 
     context 'when the validation error message was provided directly' do
       context 'given a valid value' do
@@ -537,45 +561,6 @@ invalid, but it was valid instead.
     end
   end
 
-  if active_model_3_2?
-    context 'an attribute with a strict format validation' do
-      context 'when qualified with strict' do
-        it 'rejects a bad value, providing the correct failure message' do
-          message = <<-MESSAGE.strip_heredoc
-After setting :attr to ‹"xyz"›, the matcher expected the Example to be
-valid, but it was invalid instead, raising a validation exception with
-the message "Attr is invalid".
-          MESSAGE
-
-          assertion = lambda do
-            expect(validating_format(with: /abc/, strict: true)).
-              to allow_value('xyz').for(:attr).strict
-          end
-
-          expect(&assertion).to fail_with_message(message)
-        end
-
-        context 'qualified with a custom message' do
-          it 'rejects a bad value when the failure messages do not match' do
-            message = <<-MESSAGE.strip_heredoc
-After setting :attr to ‹"xyz"›, the matcher expected the Example to be
-invalid and to raise a validation exception with message matching
-‹/abc/›. The record was indeed invalid, but the exception message was
-"Attr is invalid" instead.
-            MESSAGE
-
-            assertion = lambda do
-              expect(validating_format(with: /abc/, strict: true)).
-                not_to allow_value('xyz').for(:attr).with_message(/abc/).strict
-            end
-
-            expect(&assertion).to fail_with_message(message)
-          end
-        end
-      end
-    end
-  end
-
   context 'when the attribute interferes with attempts to be set' do
     context 'when the attribute cannot be changed from nil to non-nil' do
       context 'and the record remains valid' do
